aboutsummaryrefslogtreecommitdiff
path: root/src/client/windows/sender/crash_report_sender.h
diff options
context:
space:
mode:
authormark@chromium.org <mark@chromium.org>2014-09-03 13:40:40 +0000
committermark@chromium.org <mark@chromium.org>2014-09-03 13:40:40 +0000
commita58de86bcd085c035f3e7103b6c15fee72b97753 (patch)
treea96b5e6f783b761c15c0cdef8afcfc1c52a6ec73 /src/client/windows/sender/crash_report_sender.h
parentAdding possibility for client to upload the file (diff)
downloadbreakpad-a58de86bcd085c035f3e7103b6c15fee72b97753.tar.xz
Back out trunk r1367.
Compile error: https://bugzilla.mozilla.org/show_bug.cgi?id=1048091#c15 Review URL: https://breakpad.appspot.com/9694002 git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@1369 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/client/windows/sender/crash_report_sender.h')
-rw-r--r--src/client/windows/sender/crash_report_sender.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/client/windows/sender/crash_report_sender.h b/src/client/windows/sender/crash_report_sender.h
index 7786cc69..da1ed0af 100644
--- a/src/client/windows/sender/crash_report_sender.h
+++ b/src/client/windows/sender/crash_report_sender.h
@@ -77,7 +77,7 @@ class CrashReportSender {
int max_reports_per_day() const { return max_reports_per_day_; }
// Sends the specified files, along with the map of
// name value pairs, as a multipart POST request to the given URL.
// Parameter names must contain only printable ASCII characters,
// and may not contain a quote (") character.
@@ -89,7 +89,7 @@ class CrashReportSender {
// (Otherwise, report_code will be unchanged.)
ReportResult SendCrashReport(const wstring &url,
const map<wstring, wstring> &parameters,
- const map<wstring, wstring> &files,
+ const wstring &dump_file_name,
wstring *report_code);
private:
@@ -77,7 +77,7 @@ class CrashReportSender {
int max_reports_per_day() const { return max_reports_per_day_; }
- // Sends the specified files, along with the map of
+ // Sends the specified minidump file, along with the map of
// name value pairs, as a multipart POST request to the given URL.
// Parameter names must contain only printable ASCII characters,